==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var FastStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FastStochasticOscillatorIndicator, _super);
    function FastStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    FastStochasticOscillatorIndicator.prototype.get_t4 = function () {
        return new FastStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "t4", {
        get: function () {
            return this.get_t4();
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.get_uh = function () {
        return FastStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "up", {
        get: function () {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.uq));
        },
        set: function (a) {
            this.h(FastStochasticOscillatorIndicator.uq, a);
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.ua = function () {
        return this.up;
    };
    FastStochasticOscillatorIndicator.prototype.uj = function (a) {
        this.up = a;
    };
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.uq = StrategyBasedIndicator.um(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { FastStochasticOscillatorIndicator };

==> igniteui-react-charts-16.16.3.tgz: package/esm5/lib/FastStochasticOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { FastStochasticOscillatorIndicatorStrategy } from "./FastStochasticOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
var FastStochasticOscillatorIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FastStochasticOscillatorIndicator, _super);
    function FastStochasticOscillatorIndicator() {
        var _this = _super.call(this) || this;
        _this.trendLineBrush = ((function () {
            var $ret = new Brush();
            $ret.fill = "#565656";
            return $ret;
        })());
        _this.trendLineType = 10;
        _this.trendLinePeriod = 3;
        return _this;
    }
    FastStochasticOscillatorIndicator.prototype.get_uh = function () {
        return new FastStochasticOscillatorIndicatorStrategy();
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.get_uu = function () {
        return FastStochasticOscillatorIndicator.$;
    };
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(FastStochasticOscillatorIndicator.prototype, "u2", {
        get: function () {
            return typeGetValue(this.c(FastStochasticOscillatorIndicator.u3));
        },
        set: function (a) {
            this.h(FastStochasticOscillatorIndicator.u3, a);
        },
        enumerable: false,
        configurable: true
    });
    FastStochasticOscillatorIndicator.prototype.un = function () {
        return this.u2;
    };
    FastStochasticOscillatorIndicator.prototype.uw = function (a) {
        this.u2 = a;
    };
    FastStochasticOscillatorIndicator.$t = markType(FastStochasticOscillatorIndicator, 'FastStochasticOscillatorIndicator', StrategyBasedIndicator.$);
    FastStochasticOscillatorIndicator.u3 = StrategyBasedIndicator.uz(14, FastStochasticOscillatorIndicator.$);
    return FastStochasticOscillatorIndicator;
}(StrategyBasedIndicator));
export { FastStochasticOscillatorIndicator };
